#!/bin/bash

# 使用说明
# 操作命令
# ./make_images.sh 用户开发原型包 原镜像名 新镜像名（注意：用户开发原型包请使用tar.gz格式打包）
# 例：
# ./make_image.sh InstructionPhoneAndroidPServer.tar.gz kbox:0101 kbox:0202

set -e

cur_file_path=$(cd $(dirname "${0}");pwd)

# 构建镜像
start_time=$(date +%s)
end_time=0

# 前置条件验证
function check_env()
{
    # 用户开发原型包名称（例：InstructionPhoneAndroidPServer.tar.gz）
    local user_package=$1

    # 判断instructionEngine目录是否存在，若不存在则创建一个instructionEngine目录
    if [ ! -d "${cur_file_path}/instructionEngine/" ]; then
        echo "cur env is not exit instructionEngine directory, this directory will be created."
        mkdir -p ${cur_file_path}/instructionEngine/
    fi

    # 解压指令流商用服务端包（注意：通过--no-same-owner保证解压后的文件属组为当前操作用户（root）文件属组）
    tar --no-same-owner -zxvf ${cur_file_path}/CloudPhoneInstructionEngine.tar.gz -C instructionEngine

    # 判断instructionEngineDemo目录是否存在，若不存在则创建一个instructionEngineDemo目录
    if [ ! -d "${cur_file_path}/instructionEngineDemo/" ]; then
        echo "cur env is not exit instructionEngineDemo directory, this directory will be created."
        mkdir -p ${cur_file_path}/instructionEngineDemo/
    fi

    # 解压用户开发的指令流原型服务端包（注意：通过--no-same-owner保证解压后的文件属组为当前操作用户（root）文件属组）
    tar --no-same-owner -zxvf ${cur_file_path}/${user_package} -C instructionEngineDemo

    # 判断Dockerfile文件是否存在
    if [ ! -f "${cur_file_path}/Dockerfile" ]; then
        echo "cur env is not exit Dockerfile, please create this file." && return -1
    fi
}

# 制作镜像步骤
function make_image()
{
    ORIGIN_IMAGE=""
    # 原镜像名称（例：kbox:b032）
    local origin_image=$2
    # 新镜像名称（例：kbox:0224）
    local new_image=$3

    # 制作镜像
    echo "begin to build image."
    docker build --build-arg ORIGIN_IMAGE="${origin_image}" -t ${new_image} .
    wait
    echo "end to build image."
}

check_env $@
make_image $@

# 制作镜像时间统计
end_time=$(date +%s)
time_interval=$((${end_time}-${start_time}))
echo -e "\033[1;36m [INFO] Make image takes ${time_interval} seconds. \033[0m"